@@ -16,22 +16,20 @@
  */
 package org.apache.qpid.jms.consumer;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 
-import javax.jms.Message;
-import javax.jms.MessageListener;
-import javax.jms.Queue;
-import javax.jms.QueueReceiver;
-import javax.jms.QueueSession;
-import javax.jms.Session;
+import jakarta.jms.Message;
+import jakarta.jms.MessageListener;
+import jakarta.jms.Queue;
+import jakarta.jms.QueueReceiver;
+import jakarta.jms.QueueSession;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnectionTestSupport;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Test the basic contract of the QueueReceiver
@@ -43,30 +41,27 @@ public class JmsQueueReceiverTest extends JmsConnectionTestSupport {
     protected QueueReceiver receiver;
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
         queueConnection = createQueueConnectionToMockProvider();
         session = queueConnection.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
-        queue = session.createQueue(_testMethodName);
+        queue = session.createQueue(_testName.getMethodName());
         receiver = session.createReceiver(queue);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testMultipleCloseCalls() throws Exception {
         receiver.close();
         receiver.close();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testGetQueue() throws Exception {
         assertEquals(queue, receiver.getQueue());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testGetMessageListener() throws Exception {
         assertNull(receiver.getMessageListener());
         receiver.setMessageListener(new MessageListener() {
@@ -78,8 +73,7 @@ public class JmsQueueReceiverTest extends JmsConnectionTestSupport {
         assertNotNull(receiver.getMessageListener());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testGetMessageSelector() throws Exception {
         assertNull(receiver.getMessageSelector());
     }
