@@ -20,12 +20,12 @@ package org.apache.qpid.jms.integration;
 
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.nullValue;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -35,18 +35,18 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
 
-import javax.jms.CompletionListener;
-import javax.jms.Connection;
-import javax.jms.DeliveryMode;
-import javax.jms.JMSException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageFormatException;
-import javax.jms.MessageNotWriteableException;
-import javax.jms.MessageProducer;
-import javax.jms.ObjectMessage;
-import javax.jms.Queue;
-import javax.jms.Session;
+import jakarta.jms.CompletionListener;
+import jakarta.jms.Connection;
+import jakarta.jms.DeliveryMode;
+import jakarta.jms.JMSException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageFormatException;
+import jakarta.jms.MessageNotWriteableException;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.ObjectMessage;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport;
@@ -65,8 +65,7 @@ import org.apache.qpid.jms.test.testpeer.matchers.types.EncodedDataMatcher;
 import org.apache.qpid.jms.util.SimplePojo;
 import org.apache.qpid.proton.amqp.Binary;
 import org.apache.qpid.proton.amqp.DescribedType;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -78,20 +77,17 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
 
     //==== Java serialization encoding ====
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithSerializedContent() throws Exception {
         doSendBasicObjectMessageWithSerializedContentTestImpl("myObjectString", false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithSerializedContentExplicitNull() throws Exception {
         doSendBasicObjectMessageWithSerializedContentTestImpl(null, true);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithSerializedContentImplicitNull() throws Exception {
         doSendBasicObjectMessageWithSerializedContentTestImpl(null, false);
     }
@@ -170,8 +166,7 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBasicObjectMessageWithSerializedContent() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -212,8 +207,8 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
             ObjectMessage objectMessage = (ObjectMessage)receivedMessage;
 
             Object object = objectMessage.getObject();
-            assertNotNull(object, "Expected object but got null");
-            assertEquals(expectedContent, object, "Message body object was not as expected");
+            assertNotNull("Expected object but got null", object);
+            assertEquals("Message body object was not as expected", expectedContent, object);
 
             assertTrue(receivedMessage.isBodyAssignableTo(String.class));
             assertTrue(receivedMessage.isBodyAssignableTo(Serializable.class));
@@ -236,8 +231,7 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveAndThenResendBasicObjectMessageWithSerializedContent() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -315,43 +309,37 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBlockedSerializedContentFailsOnGetObject() throws Exception {
         // We aren't allowing the test class
         doTestReceiveSerializedContentPolicyTest("java.lang,java.util", null, false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBlockAllSerializedContentFailsOnGetObject() throws Exception {
         // We are blocking everything
         doTestReceiveSerializedContentPolicyTest(null, "*", false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBlockSomeSerializedContentFailsOnGetObject() throws Exception {
         // We aren't allowing the UUID
         doTestReceiveSerializedContentPolicyTest("org.apache.qpid.jms", null, false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveWithWrongUnblockedSerializedContentFailsOnGetObject() throws Exception {
         // We aren't allowing the UUID a different way
         doTestReceiveSerializedContentPolicyTest("java.lang,org.apache.qpid.jms", null, false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveWithFullyAllowedSerializedContentSucceeds() throws Exception {
         // We are allowing everything needed
         doTestReceiveSerializedContentPolicyTest("java.lang,java.util,org.apache.qpid.jms", null, true);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveWithFullyAllowedSerializedContentFailsDueToDenyList() throws Exception {
         // We are allowing everything needed, but then the deny list is overriding to block some
         doTestReceiveSerializedContentPolicyTest("java.lang,java.util,org.apache.qpid.jms", "java.util", false);
@@ -425,7 +413,7 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
             }
 
             if (succeed) {
-                assertEquals(expectedContent, received, "Content not as expected");
+                assertEquals("Content not as expected", expectedContent, received);
             }
 
             testPeer.expectClose();
@@ -437,8 +425,7 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
 
     //==== AMQP type system encoding ====
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithAmqpTypedContent() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -493,8 +480,7 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testRecieveBasicObjectMessageWithAmqpTypedContentAndJMSMessageTypeAnnotation() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -522,12 +508,12 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
             Message receivedMessage = messageConsumer.receive(3000);
 
             assertNotNull(receivedMessage);
-            assertTrue(receivedMessage instanceof ObjectMessage, "Expected ObjectMessage instance, but got: " + receivedMessage.getClass().getName());
+            assertTrue("Expected ObjectMessage instance, but got: " + receivedMessage.getClass().getName(), receivedMessage instanceof ObjectMessage);
             ObjectMessage objectMessage = (ObjectMessage)receivedMessage;
 
             Object object = objectMessage.getObject();
-            assertNotNull(object, "Expected object but got null");
-            assertEquals(map, object, "Message body object was not as expected");
+            assertNotNull("Expected object but got null", object);
+            assertEquals("Message body object was not as expected", map, object);
 
             assertTrue(receivedMessage.isBodyAssignableTo(Map.class));
             assertTrue(receivedMessage.isBodyAssignableTo(Serializable.class));
@@ -550,8 +536,7 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncSendDoesNotMarkObjectMessageReadOnly() throws Exception {
         try(TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JmsConnection connection = (JmsConnection) testFixture.establishConnecton(testPeer);
@@ -654,13 +639,11 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncCompletionSendMarksObjectMessageReadOnly() throws Exception {
         try(TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JmsConnection connection = (JmsConnection) testFixture.establishConnecton(testPeer);
             connection.setSendTimeout(15000);
-            connection.setCloseTimeout(10);
 
             testPeer.expectBegin();
 
