@@ -22,12 +22,12 @@ import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.both;
 import static org.hamcrest.Matchers.greaterThanOrEqualTo;
 import static org.hamcrest.Matchers.lessThanOrEqualTo;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyInt;
@@ -41,23 +41,19 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
 
-import javax.jms.BytesMessage;
-import javax.jms.CompletionListener;
-import javax.jms.DeliveryMode;
-import javax.jms.Destination;
-import javax.jms.IllegalStateException;
-import javax.jms.IllegalStateRuntimeException;
-import javax.jms.InvalidDestinationException;
-import javax.jms.InvalidDestinationRuntimeException;
-import javax.jms.JMSException;
-import javax.jms.JMSProducer;
-import javax.jms.JMSRuntimeException;
-import javax.jms.MapMessage;
-import javax.jms.Message;
-import javax.jms.MessageFormatRuntimeException;
-import javax.jms.ObjectMessage;
-import javax.jms.Queue;
-import javax.jms.TextMessage;
+import jakarta.jms.CompletionListener;
+import jakarta.jms.DeliveryMode;
+import jakarta.jms.Destination;
+import jakarta.jms.IllegalStateException;
+import jakarta.jms.IllegalStateRuntimeException;
+import jakarta.jms.InvalidDestinationException;
+import jakarta.jms.InvalidDestinationRuntimeException;
+import jakarta.jms.JMSException;
+import jakarta.jms.JMSProducer;
+import jakarta.jms.JMSRuntimeException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageFormatRuntimeException;
+import jakarta.jms.Queue;
 
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsConnectionTestSupport;
@@ -72,11 +68,9 @@ import org.apache.qpid.jms.message.JmsOutboundMessageDispatch;
 import org.apache.qpid.jms.meta.JmsSessionId;
 import org.apache.qpid.jms.provider.mock.MockRemotePeer;
 import org.hamcrest.Matcher;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 import org.mockito.Mockito;
 
 /**
@@ -121,16 +115,16 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
     private final String JMS_TYPE_STRING = "TestType";
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
 
         remotePeer.start();
         context = createJMSContextToMockProvider();
     }
 
     @Override
-    @AfterEach
+    @After
     public void tearDown() throws Exception {
         try {
             context.close();
@@ -793,8 +787,7 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         assertEquals(DeliveryMode.NON_PERSISTENT, producer.getDeliveryMode());
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout = 10000)
     public void testDeliveryModeConfigurationWithInvalidMode() throws Exception {
         JMSProducer producer = context.createProducer();
 
@@ -855,8 +848,7 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         assertEquals(4, producer.getPriority());
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout = 10000)
     public void testPriorityConfigurationWithInvalidPriorityValues() throws Exception {
         JMSProducer producer = context.createProducer();
 
@@ -1012,18 +1004,18 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         doTestSendAppliesDeliveryModeWithMessageBody(UUID.class);
     }
 
-    private void doTestSendAppliesDeliveryModeWithMessageBody(Class<?> bodyType) throws JMSException {
+    public void doTestSendAppliesDeliveryModeWithMessageBody(Class<?> bodyType) throws JMSException {
         JMSProducer producer = context.createProducer();
 
         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
-        sendWithBodyOfType(producer, bodyType);
+        producer.send(JMS_DESTINATION, "text");
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
         assertEquals(DeliveryMode.PERSISTENT, message.getJMSDeliveryMode());
 
         producer.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
-        sendWithBodyOfType(producer, bodyType);
+        producer.send(JMS_DESTINATION, "text");
         envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         message = envelope.getMessage();
@@ -1214,25 +1206,9 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof TextMessage);
         assertEquals(bodyValue, message.getBody(String.class));
     }
 
-    @Test
-    public void testStringNullBodyGivesEmptyMessage() throws JMSException {
-        JMSProducer producer = context.createProducer();
-
-        final String nullStringBody = null;
-        producer.send(JMS_DESTINATION, nullStringBody);
-
-        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
-        assertNotNull(envelope);
-
-        JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof TextMessage);
-        assertNull(message.getBody(String.class));
-    }
-
     @Test
     public void testMapBodyIsApplied() throws JMSException {
         JMSProducer producer = context.createProducer();
@@ -1246,25 +1222,9 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof MapMessage);
         assertEquals(bodyValue, message.getBody(Map.class));
     }
 
-    @Test
-    public void testMapNullBodyGivesEmptyMessage() throws JMSException {
-        JMSProducer producer = context.createProducer();
-
-        final Map<String, Object> nullMapBody = null;
-        producer.send(JMS_DESTINATION, nullMapBody);
-
-        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
-        assertNotNull(envelope);
-
-        JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof MapMessage);
-        assertNull(message.getBody(Map.class));
-    }
-
     @Test
     public void testBytesBodyIsApplied() throws JMSException {
         JMSProducer producer = context.createProducer();
@@ -1275,7 +1235,6 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof BytesMessage);
 
         byte[] payload = message.getBody(byte[].class);
         assertNotNull(payload);
@@ -1286,21 +1245,6 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         }
     }
 
-    @Test
-    public void testBytesNullBodyGivesEmptyMessage() throws JMSException {
-        JMSProducer producer = context.createProducer();
-
-        final byte[] nullBytesBody = null;
-        producer.send(JMS_DESTINATION, nullBytesBody);
-
-        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
-        assertNotNull(envelope);
-
-        JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof BytesMessage);
-        assertNull(message.getBody(byte[].class));
-    }
-
     @Test
     public void testSerializableBodyIsApplied() throws JMSException {
         JMSProducer producer = context.createProducer();
@@ -1311,25 +1255,9 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof ObjectMessage);
         assertEquals(bodyValue, message.getBody(UUID.class));
     }
 
-    @Test
-    public void testSerializableNullBodyGivesEmptyMessage() throws JMSException {
-        JMSProducer producer = context.createProducer();
-
-        final UUID nullSerializableBody = null;
-        producer.send(JMS_DESTINATION, nullSerializableBody);
-
-        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
-        assertNotNull(envelope);
-
-        JmsMessage message = envelope.getMessage();
-        assertTrue(message instanceof ObjectMessage);
-        assertNull(message.getBody(byte[].class));
-    }
-
     //----- Test for conversions to JMSRuntimeException ----------------------//
 
     @Test
